==> NETXave-0.0.2.crate: NETXave-0.0.2/src/protocols/dns/client/types/dns/hrcodes/rcode_info.rs <==
/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

pub struct RCODEInfo {
    rcode: u16,
    name: &'static str,
    description: &'static str
}

impl RCODEInfo {
    pub fn new(rcode: u16, name: &'static str, description: &'static str) -> RCODEInfo {
        return RCODEInfo {
            rcode: rcode,
            name: name,
            description: description
        }
    }

    pub fn rcode(&self) -> &u16 {
        return &self.rcode;
    }

    pub fn name(&self) -> &'static str {
        return &self.name;
    }

    pub fn description(&self) -> &'static str {
        return &self.description;
    }

    pub fn hex(&self) -> String {
        return format!("{:02x}", &self.rcode);
    }
}

==> NETXave-0.0.3.crate: NETXave-0.0.3/src/protocols/dns/client/types/dns/hrcodes/rcode_info.rs <==
/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

use crate::data_types::{U4};

pub struct RCODEInfo {
    rcode: U4,
    name: &'static str,
    description: &'static str
}

impl RCODEInfo {
    pub fn new(rcode: U4, name: &'static str, description: &'static str) -> RCODEInfo {
        return RCODEInfo {
            rcode: rcode,
            name: name,
            description: description
        }
    }

    pub fn rcode(&self) -> &U4 {
        return &self.rcode;
    }

    pub fn name(&self) -> &'static str {
        return &self.name;
    }

    pub fn description(&self) -> &'static str {
        return &self.description;
    }

    pub fn hex(&self) -> String {
        return format!("{:02x}", &self.rcode.get());
    }
}
